@@ -2,9 +2,9 @@ import sys
 import gdb
 
 # Update module path.
-dir = '/usr/local/share/glib-2.0/gdb'
-if not dir in sys.path:
-    sys.path.insert(0, dir)
+dir_ = '/usr/local/share/glib-2.0/gdb'
+if not dir_ in sys.path:
+    sys.path.insert(0, dir_)
 
 from gobject import register
 register (gdb.current_objfile ())
